<template>
  <a-card :bordered='false' :class="'cust-erp-sub-tab'">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form
        layout="inline"
        @keyup.enter.native="searchQuery"
      >
        <a-row :gutter="24">
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class='table-operator' v-if='mainId.id'>
      <a-dropdown v-if='selectedRowKeys.length > 0'>
        <a-menu slot='overlay'>
          <a-menu-item key='1' @click='batchDel'>
            <a-icon type='delete' />
            删除
          </a-menu-item>
        </a-menu>
        <a-button style='margin-left: 8px'> 批量操作
          <a-icon type='down' />
        </a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <!-- <div class='ant-alert ant-alert-info' style='margin-bottom: 16px;'>
        <i class='anticon anticon-info-circle ant-alert-icon'></i> 已选择 <a
        style='font-weight: 600'>{{ selectedRowKeys.length }}</a>项
        <a style='margin-left: 24px' @click='onClearSelected'>清空</a>
      </div> -->

      <a-table
        ref='table'
        size='middle'
        bordered
        rowKey='id'
        :scroll='{x:true}'
        :columns='columns'
        :dataSource='dataSource'
        :pagination='ipagination'
        :loading='loading'
        @change='handleTableChange'>
        <!-- :rowSelection='{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}' -->



        <span slot='action' slot-scope='text, record'>
          <!-- <a @click='handleEdit(record)'>编辑</a>
          <a-divider type='vertical' /> -->
          <a-popconfirm title='确定删除吗?' @confirm='() => handleDelete(record.id)'>
            <a v-if="record.isLock=='no'&&mainId.status=='3'">删除</a>
          </a-popconfirm>
        </span>

      </a-table>
      <a-button
      style="width: 100%; margin-top: 16px; margin-bottom: 8px"
      type="dashed"
      icon="plus"
      @click="handleAdd"
      :disabled="mainId.status=='4'"
    >添加故障分析
    </a-button>
    </div>
    <repair-order-fault-analysis-report-model
      ref='modalForm'
      @ok='modalFormOk'
    ></repair-order-fault-analysis-report-model>
  </a-card>


</template>

<script>

import { JeecgListMixin } from '@/mixins/JeecgListMixin'


import RepairOrderFaultAnalysisReportModel from './RepairOrderFaultAnalysisReportModel.vue'

export default {
  name: 'RepairOrderFaultAnalysisList',
  mixins: [JeecgListMixin],
  components: { RepairOrderFaultAnalysisReportModel },
  props: {
    mainId: {
      type: Object,
    }
  },
  watch: {
    mainId: {
      immediate: true,
      handler(val) {
        console.log(val)
        if (!this.mainId.id) {

          this.clearList()
        } else {

          this.queryParam['repairOrderId'] = val.id
          this.loadData(1)
        }
      }
    }
  },

  data() {
    return {
      description: '维修工单管理页面',
      disableMixinCreated: true,
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '故障原因',
          dataIndex: 'faultCauseName',
          align: 'center',
          width: 150,
          ellipsis: true,
        },
        {
          title: '故障类型',
          dataIndex: 'faultTypeName',
          align: 'center',
          width: 150,
          ellipsis: true,
        },
        {
          title: '故障分析',
          dataIndex: 'faultCause',
          align: 'center',
          width: 150,
          ellipsis: true,
        },
        {
          title: '维修措施',
          dataIndex: 'maintenanceMeasures',
          align: 'center',
          width: 150,
          ellipsis: true,
        },
        {
          title: '维保改进意见',
          dataIndex: 'suggestion',
          align: 'center',
          width: 150,
          ellipsis: true,
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          width: 147,
          scopedSlots: { customRender: 'action' }
        }
      ],
      url: {
        list: '/eam/repairOrder/listRepairOrderFaultAnalysisByMainId',
        delete: '/eam/repairOrder/deleteRepairOrderFaultAnalysis',
        deleteBatch: '/eam/repairOrder/deleteBatchRepairOrderFaultAnalysis',
        exportXlsUrl: '/eam/repairOrder/exportRepairOrderFaultAnalysis',
        importUrl: '/eam/repairOrder/importRepairOrderFaultAnalysis'
      },
      dictOptions: {}
    }
  },
  created() {
  },
  computed: {
    importExcelUrl() {
      return `${window._CONFIG['domianURL']}/${this.url.importUrl}/${this.mainId.id}`
    }
  },
  methods: {
    clearList() {
      this.dataSource = []
      this.selectedRowKeys = []
      this.ipagination.current = 1
    },
    handleAdd: function() {
      this.$refs.modalForm.add(this.mainId)
      this.$refs.modalForm.title = '新增'
      this.$refs.modalForm.disableSubmit = false
    },

  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>
